==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_fields/ASSETINVENTORYID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour ASSETINVENTORYID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="ASSETINVENTORYID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASSETINVENTORYCODE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ASSETINVENTORYID_Type", propOrder = {
    "assetinventorycode"
})
public class ASSETINVENTORYID_Type {

    @XmlElement(name = "ASSETINVENTORYCODE", required = true)
    protected String assetinventorycode;

    /**
     * Obtient la valeur de la propriété assetinventorycode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getASSETINVENTORYCODE() {
        return assetinventorycode;
    }

    /**
     * Définit la valeur de la propriété assetinventorycode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setASSETINVENTORYCODE(String value) {
        this.assetinventorycode = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/ASSETINVENTORYID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ASSETINVENTORYID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="ASSETINVENTORYID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASSETINVENTORYCODE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ASSETINVENTORYID_Type", propOrder = {
    "assetinventorycode"
})
public class ASSETINVENTORYID_Type {

    @XmlElement(name = "ASSETINVENTORYCODE", required = true)
    protected String assetinventorycode;

    /**
     * Gets the value of the assetinventorycode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getASSETINVENTORYCODE() {
        return assetinventorycode;
    }

    /**
     * Sets the value of the assetinventorycode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setASSETINVENTORYCODE(String value) {
        this.assetinventorycode = value;
    }

}
